<!--
*** Thanks for checking out this README Template. If you have a suggestion that would
*** make this better, please fork the repo and create a pull request or simply open
*** an issue with the tag "enhancement".
*** Thanks again! Now go create something AMAZING! :D
-->

  <h3 align="center">Claude package</h3>

  <p align="center">
    Exponential Random Graph models to build null models for networks analysis 
    <br />
    <a href="[repo-url]"><strong>Explore the docs (WIP)»</strong></a>
    <br />
    <br />
    <a href="https://github.com/reemagit/claude/blob/master/demos/main_demo.ipynb">View Demos</a>
  </p>
</p>

## Installation

```sh
pip install pyclaude
```

## Requirements

* scipy
* tqdm
